@@ -1,7 +1,7 @@
 package Huawei::Healthchecker;
 
 #版本信息
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 use strict;
 use warnings;
@@ -824,7 +824,7 @@ sub ntp_status {
 
  #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
-        if (/synchronization state/i) {
+        if (/clock status/i) {
 
             #将巡检结果命令行分割为字符串数组
             my @info = map {s/(^\s+|\s+$)//r} split( /\:/, $_ );
@@ -837,11 +837,11 @@ sub ntp_status {
 
             #写入异常状态
             $result->{"log"} = "NTP时钟源未同步"
-                if ( $status =~ /not/i );
+                if ( $status eq "unsynchronized" );
             $result->{"alarm"} = "info";
 
             #监控检查状态
-            $result->{"health"} = "fail";
+            $result->{"health"} = "fail" if ( $status eq "unsynchronized" );
         }
     }
 
